@@ -1,5 +1,5 @@
 """
-This file is part of pycos project. See https://pycos.sourceforge.io for details.
+This file is part of pycos; see https://pycos.org for details.
 
 This module adds API for distributed programming to Pycos.
 """
@@ -39,7 +39,7 @@ else:
 __author__ = "Giridhar Pemmasani (pgiri@yahoo.com)"
 __copyright__ = "Copyright (c) 2012-2014 Giridhar Pemmasani"
 __license__ = "Apache 2.0"
-__url__ = "https://pycos.sourceforge.io"
+__url__ = "https://pycos.org"
 
 __version__ = pycos.__version__
 __all__ = pycos.__all__ + ['PeerStatus', 'RPS', 'RTI']
@@ -1516,6 +1516,7 @@ class RPS(object):
                 logger.debug('RPS: rtask %s done: %s', rtask, msg.value)
                 rtask._value = msg.value
             else:
+                rtask._value = msg
                 logger.warning('RPS: rtask %s failed: %s%s', rtask, msg.type,
                                ' with %s' % msg.value if isinstance(msg.value, str) else '')
             rtask._complete.set()
